@@ -11,6 +11,7 @@ from hyperliquid.utils.constants import MAINNET_API_URL
 from hyperliquid.utils.signing import (
     CancelByCloidRequest,
     CancelRequest,
+    Grouping,
     ModifyRequest,
     OidOrCloid,
     OrderRequest,
@@ -48,6 +49,10 @@ from hyperliquid.utils.types import (
 )
 
 
+def _get_dex(coin: str) -> str:
+    return coin.split(":")[0] if ":" in coin else ""
+
+
 class Exchange(API):
     # Default Max Slippage for Market Orders 5%
     DEFAULT_SLIPPAGE = 0.05
@@ -91,7 +96,8 @@ class Exchange(API):
         coin = self.info.name_to_coin[name]
         if not px:
             # Get midprice
-            px = float(self.info.all_mids()[coin])
+            dex = _get_dex(coin)
+            px = float(self.info.all_mids(dex)[coin])
 
         asset = self.info.coin_to_asset[coin]
         # spot assets start at 10000
@@ -131,7 +137,9 @@ class Exchange(API):
             order["cloid"] = cloid
         return self.bulk_orders([order], builder)
 
-    def bulk_orders(self, order_requests: List[OrderRequest], builder: Optional[BuilderInfo] = None) -> Any:
+    def bulk_orders(
+        self, order_requests: List[OrderRequest], builder: Optional[BuilderInfo] = None, grouping: Grouping = "na"
+    ) -> Any:
         order_wires: List[OrderWire] = [
             order_request_to_order_wire(order, self.info.name_to_asset(order["coin"])) for order in order_requests
         ]
@@ -139,7 +147,7 @@ class Exchange(API):
 
         if builder:
             builder["b"] = builder["b"].lower()
-        order_action = order_wires_to_order_action(order_wires, builder)
+        order_action = order_wires_to_order_action(order_wires, builder, grouping)
 
         signature = sign_l1_action(
             self.wallet,
@@ -242,7 +250,8 @@ class Exchange(API):
             address = self.account_address
         if self.vault_address:
             address = self.vault_address
-        positions = self.info.user_state(address)["assetPositions"]
+        dex = _get_dex(coin)
+        positions = self.info.user_state(address, dex)["assetPositions"]
         for position in positions:
             item = position["position"]
             if coin != item["coin"]:
