@@ -1,3 +1,5 @@
+from typing import Any
+
 import time
 from decimal import Decimal
 
@@ -104,6 +106,24 @@ USD_CLASS_TRANSFER_SIGN_TYPES = [
     {"name": "nonce", "type": "uint64"},
 ]
 
+SEND_ASSET_SIGN_TYPES = [
+    {"name": "hyperliquidChain", "type": "string"},
+    {"name": "destination", "type": "string"},
+    {"name": "sourceDex", "type": "string"},
+    {"name": "destinationDex", "type": "string"},
+    {"name": "token", "type": "string"},
+    {"name": "amount", "type": "string"},
+    {"name": "fromSubAccount", "type": "string"},
+    {"name": "nonce", "type": "uint64"},
+]
+
+USER_DEX_ABSTRACTION_SIGN_TYPES = [
+    {"name": "hyperliquidChain", "type": "string"},
+    {"name": "user", "type": "address"},
+    {"name": "enabled", "type": "bool"},
+    {"name": "nonce", "type": "uint64"},
+]
+
 TOKEN_DELEGATE_TYPES = [
     {"name": "hyperliquidChain", "type": "string"},
     {"name": "validator", "type": "address"},
@@ -341,6 +361,26 @@ def sign_usd_class_transfer_action(wallet, action, is_mainnet):
     )
 
 
+def sign_send_asset_action(wallet, action, is_mainnet):
+    return sign_user_signed_action(
+        wallet,
+        action,
+        SEND_ASSET_SIGN_TYPES,
+        "HyperliquidTransaction:SendAsset",
+        is_mainnet,
+    )
+
+
+def sign_user_dex_abstraction_action(wallet, action, is_mainnet):
+    return sign_user_signed_action(
+        wallet,
+        action,
+        USER_DEX_ABSTRACTION_SIGN_TYPES,
+        "HyperliquidTransaction:UserDexAbstraction",
+        is_mainnet,
+    )
+
+
 def sign_convert_to_multi_sig_user_action(wallet, action, is_mainnet):
     return sign_user_signed_action(
         wallet,
@@ -392,7 +432,8 @@ def sign_token_delegate_action(wallet, action, is_mainnet):
 
 
 def sign_inner(wallet, data):
-    signed = wallet.sign_typed_data(full_message=data)
+    structured_data = encode_typed_data(full_message=data)
+    signed = wallet.sign_message(structured_data)
     return {"r": to_hex(signed["r"]), "s": to_hex(signed["s"]), "v": signed["v"]}
 
 
@@ -457,11 +498,11 @@ def order_request_to_order_wire(order: OrderRequest, asset: int) -> OrderWire:
     return order_wire
 
 
-def order_wires_to_order_action(order_wires, builder=None):
+def order_wires_to_order_action(order_wires: list[OrderWire], builder: Any = None, grouping: Grouping = "na") -> Any:
     action = {
         "type": "order",
         "orders": order_wires,
-        "grouping": "na",
+        "grouping": grouping,
     }
     if builder:
         action["builder"] = builder
